'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = undefined;

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

var _get2 = require('lodash/get');

var _get3 = _interopRequireDefault(_get2);

var _has2 = require('lodash/has');

var _has3 = _interopRequireDefault(_has2);

var _isArray2 = require('lodash/isArray');

var _isArray3 = _interopRequireDefault(_isArray2);

var _team = require('./team');

Object.defineProperty(exports, 'default', {
  enumerable: true,
  get: function get() {
    return _interopRequireDefault(_team).default;
  }
});

require('@ciscospark/internal-plugin-conversation');

require('@ciscospark/internal-plugin-user');

require('@ciscospark/internal-plugin-encryption');

var _sparkCore = require('@ciscospark/spark-core');

var _team2 = _interopRequireDefault(_team);

var _config = require('./config');

var _config2 = _interopRequireDefault(_config);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/*!
 * Copyright (c) 2015-2017 Cisco Systems, Inc. See LICENSE file.
 */

(0, _sparkCore.registerInternalPlugin)('team', _team2.default, {
  payloadTransformer: {
    predicates: [{
      name: 'decryptTeamRoomStatus',
      direction: 'inbound',
      test: function test(ctx, optionsOrResponse) {
        return _promise2.default.resolve((0, _has3.default)(optionsOrResponse, 'activity.object.activityEvent') && (0, _get3.default)(optionsOrResponse, 'activity.object.objectType') === 'teamRoomStatus');
      },
      extract: function extract(optionsOrResponse) {
        return _promise2.default.resolve(optionsOrResponse.activity.object);
      }
    }],
    transforms: [{
      name: 'decryptTeam',
      direction: 'inbound',
      fn: function fn(ctx, key, team) {
        var promises = [];

        if (team.conversations.items) {
          promises.push(_promise2.default.all(team.conversations.items.map(function (item) {
            return ctx.transform('decryptObject', null, item);
          })));
        }

        var usableKey = team.encryptionKeyUrl || key;

        if (usableKey) {
          promises.push(ctx.transform('decryptPropDisplayName', usableKey, team));
          promises.push(ctx.transform('decryptPropSummary', usableKey, team));
        }

        return _promise2.default.all(promises);
      }
    }, {
      name: 'decryptTeamRoomStatus',
      direction: 'inbound',
      fn: function fn(ctx, teamRoomStatus) {
        var keyUrl = (0, _get3.default)(teamRoomStatus, 'activityEvent.encryptionKeyUrl');

        return ctx.transform('decryptObject', keyUrl, teamRoomStatus.activityEvent);
      }
    }, {
      name: 'decryptPropSummary',
      direction: 'inbound',
      fn: function fn(ctx, key, team) {
        return ctx.transform('decryptTextProp', 'summary', key, team);
      }
    }, {
      name: 'encryptTeam',
      direction: 'outbound',
      fn: function fn(ctx, key, team) {
        if (key === false) {
          return _promise2.default.resolve();
        }

        return _promise2.default.resolve(key || ctx.spark.internal.encryption.kms.createUnboundKeys({ count: 1 })).then(function (keys) {
          var k = (0, _isArray3.default)(keys) ? keys[0] : keys;

          if (team.kmsMessage && team.kmsMessage.keyUris && !team.kmsMessage.keyUris.includes(k.uri)) {
            team.kmsMessage.keyUris.push(k.uri);
          }

          return _promise2.default.all([ctx.transform('encryptPropDisplayName', k, team), ctx.transform('encryptPropSummary', k, team)]).then(function () {
            team.encryptionKeyUrl = k.uri || k;

            // we only want to set the defaultActivityEncryptionKeyUrl if we've
            // bound a new key
            if (!key) {
              team.defaultActivityEncryptionKeyUrl = team.defaultActivityEncryptionKeyUrl || k.uri || k;
            }
          });
        });
      }
    }, {
      name: 'encryptPropSummary',
      direction: 'outbound',
      fn: function fn(ctx, key, team) {
        return ctx.transform('encryptTextProp', 'summary', key, team);
      }
    }, {
      name: 'normalizeTeam',
      fn: function fn(ctx, team) {
        team.conversations = team.conversations || {};
        team.conversations.items = team.conversations.items || [];
        team.teamMembers = team.teamMembers || {};
        team.teamMembers.items = team.teamMembers.items || [];

        return _promise2.default.all([_promise2.default.all(team.conversations.items.map(function (item) {
          return ctx.transform('normalizeObject', item);
        })), _promise2.default.all(team.teamMembers.items.map(function (item) {
          return ctx.transform('normalizeObject', item);
        }))]);
      }
    }]
  },
  config: _config2.default
});
//# sourceMappingURL=index.js.map
